@@ -1186,6 +1186,58 @@ SCSS
 
   # Regression Tests
 
+  def test_nested_extend_specificity
+    assert_equal <<CSS, render(<<SCSS)
+a :b, a :b:c {
+  a: b; }
+CSS
+%foo {a: b}
+
+a {
+  :b {@extend %foo}
+  :b:c {@extend %foo}
+}
+SCSS
+  end
+
+  def test_nested_double_extend_optimization
+    assert_equal <<CSS, render(<<SCSS)
+.parent1 .child {
+  a: b; }
+CSS
+%foo %bar {
+  a: b;
+}
+
+.parent1 {
+  @extend %foo;
+
+  .child {
+    @extend %bar;
+  }
+}
+
+.parent2 {
+  @extend %foo;
+}
+SCSS
+  end
+
+  def test_extend_in_double_nested_media_query
+    assert_equal <<CSS, render(<<SCSS)
+@media all and (orientation: landscape) {
+  .bar {
+    color: blue; } }
+CSS
+@media all {
+  @media (orientation: landscape) {
+    %foo {color: blue}
+    .bar {@extend %foo}
+  }
+}
+SCSS
+  end
+
   def test_partially_failed_extend
     assert_no_warning {assert_equal(<<CSS, render(<<SCSS))}
 .rc, test {
